==> abasic_0_0_7_3.zip: abasic_0_0_7_3/sample/sql/main.cpp <==
//WindowsAvP[VɑgݍŃf[^x[X𑀍삷Tv
#include <stdio.h>
#include <string.h>
#include <windows.h>
#include <process.h>
#include "resource.h"
#include "../abasic/ap_if.h"
#include "sql.h"

#pragma warning( disable : 4996 )

void OpenFileDlg(HWND hWnd,char*filename,int buffSize);
void thread(char*filename);
int WINAPI WinMain(HINSTANCE hCurInst,HINSTANCE hPrevInst,LPSTR lpsCmdLine,int nCmdShow );
BOOL CALLBACK DlgProc1(HWND,UINT,WPARAM,LPARAM);

HWND hDlg;
char filename[1024]="";
static char buff[65535];
static char p_buff[65535];
//}`Xbh΍
HANDLE     hIOMutex = CreateMutex (NULL, FALSE, NULL);

//t@C_CAO̕\
void OpenFileDlg(HWND hWnd,char*filename,int buffSize){
	OPENFILENAME OpenFileName;
	memset(&OpenFileName,0,sizeof(OPENFILENAME));
	OpenFileName.lStructSize=sizeof(OPENFILENAME);
	OpenFileName.hwndOwner = hWnd;
	OpenFileName.lpstrFilter = TEXT("*.csv(CSVt@C)\0")
				   TEXT("*.csv\0")
				   TEXT("*.*(̑)\0*.*\0\0");
	OpenFileName.nFilterIndex =0;
	OpenFileName.lpstrFile = filename;
	OpenFileName.nMaxFile = buffSize;
	OpenFileName.lpstrTitle = "t@CJ";
	OpenFileName.Flags = OFN_FILEMUSTEXIST | OFN_HIDEREADONLY | OFN_NOCHANGEDIR;
	if(!GetOpenFileName(&OpenFileName)) filename[0]='\0';
}

//[J[Xbh
void thread(char*filename){
	//}`Xbh΍
	WaitForSingleObject( hIOMutex, INFINITE );
	//ʓ͂𖳌
	EnableWindow(GetDlgItem(hDlg,IDC_EDIT1),false);
	EnableWindow(GetDlgItem(hDlg,IDC_BUTTON1),false);
	EnableWindow(GetDlgItem(hDlg,IDC_BUTTON2),false);

	HENV   henv=NULL;//ODBC nh
	HDBC   hdbc=NULL;//ODBC ڑnh
	HSTMT  hstmt=NULL;//ODBC Xe[ggEnh
	
	//C^v^̊֐inits
	basic_func("init");

	char sql_source[256];
	char sql_user[256];
	char sql_pass[256];

	//C^v^ODBCڑ擾
	strcpy(sql_source,(char*)basic_getVari("sql_source"));
	strcpy(sql_user,(char*)basic_getVari("sql_user"));
	strcpy(sql_pass,(char*)basic_getVari("sql_pass"));

	//o^JEgJE^
	int counter=0;

	FILE * wfp;
	//Ot@CJ
	if((wfp=fopen("./log.txt","w"))==NULL){
		MessageBox(hDlg,"t@Cۑł܂","t@Cۑł܂",0);
	}else{
		FILE * rfp;
		//Ҍf[^t@CJ
		if((rfp=fopen(filename,"r"))==NULL){
			MessageBox(hDlg,"t@CJ܂","t@CJ܂",0);
		}else{
			while(fgets(buff,sizeof(buff),rfp)!=NULL){
				if(0==counter%100){
					//ODBCؒf
					Close(&henv,&hdbc,&hstmt);
					//ڑ ODBCf[^\[X [U[ pX[h
					if(!Connect(sql_source,sql_user,sql_pass,&henv,&hdbc,&hstmt)){
						MessageBox(hDlg,"ODBCڑG[","ODBCڑG[",0);
						return;
					}
				}
				//CR  LF 菜
				char*pos=buff;
				while(*pos){
					if(0x0D==*pos || 0x0A==*pos){
						*pos='\0';
						break;
					}
					pos++;
				}

				//C^v^̕ϐdataɃt@C̈ŝ܂܏
				basic_setVari("data",buff);
				//C^v^̊֐runs邽߂̏
				basic_setVari("callback","@run");
				//gUNV̊Jn R~bgOFFɂ
				if('1'!=*basic_getVari("debug")) SQLSetConnectOption( hdbc, SQL_AUTOCOMMIT, SQL_AUTOCOMMIT_OFF );
				
				do{
					//C^v^̃R[擾
					strcpy(p_buff,(const char*)basic_getVari("callback"));
					//R[i[ĂϐNA
					basic_setVari("callback","");
					//C^v^s
					basic_goto(p_buff);
					//C^v^֓nʂ
					basic_setVari("sql_result","");

					//C^v^ō\G[ꍇDB[obNI
					if('\0'!=*basic_getVari("system.err.line")){
						MessageBox(NULL,(char*)basic_getVari("system.err.line"),"C^v^\G[",0);
						MessageBox(NULL,(char*)basic_getVari("system.err.msg"),"\G[bZ[W",0);
						SQLTransact( henv, hdbc, SQL_ROLLBACK );
						Close(&henv,&hdbc,&hstmt);
						return;
					}

					//C^v^sSQL擾
					sprintf(p_buff,"%s",basic_getVari("sql"));
					//擾̕ϐNA
					basic_setVari("sql","");

					//sSQL݂s
					if(*p_buff){
						//C^v^̕ϐsqlɊi[ꂽSQLt@Cɕۑ
						fprintf(wfp,"%s\n",p_buff);
						fflush(wfp);

						//SQL̎s
						if(!Execute(&henv,&hdbc,&hstmt,p_buff)){
							MessageBox(hDlg,p_buff,"SQLG[",0);
							SQLTransact( henv, hdbc, SQL_ROLLBACK );
							Close(&henv,&hdbc,&hstmt);
							return;
						}
						
						//ʂ̃J̐߂
						short cols=0;
						SQLNumResultCols(hstmt, &cols);
						//SQĽʂɖ߂l
						if(cols){
							unsigned char  str[256];//tB[hőTCY
							long le;//NULL̔ -1NULL

							//AvP[Vϐւ̗̃oCh(ϐɊ֘At)
							SQLBindCol(hstmt, 1, SQL_C_CHAR, &str, (SDWORD)sizeof(str),&le);

							while(1){
								RETCODE rc = SQLFetch(hstmt);

								if( rc == SQL_NO_DATA_FOUND )
									break;
								if( rc != SQL_SUCCESS && rc != SQL_SUCCESS_WITH_INFO ) {
									//DBG[
									MessageBox(NULL,"DBG[","DBG[",0);
									SQLTransact( henv, hdbc, SQL_ROLLBACK );
									Close(&henv,&hdbc,&hstmt);
									return;
								}
								//ʂ̖߂lC^v^֕ԂϐɊi[
								basic_setVari("sql_result",(char*)str);
							}

							SQLFreeStmt(hstmt, SQL_DROP);//Xe[ggEnh̉
							SQLAllocStmt(hdbc, &hstmt);//Xe[ggEnh̍Ċ蓖
						}
					}
				}while(*(basic_getVari("callback")));//R[obNw肳ĂJԂ

				//gUNV̏I
				if('1'!=*basic_getVari("debug")) SQLTransact( henv, hdbc, SQL_COMMIT );
				
				//ʏɏꂽJE^̐\
				sprintf(p_buff,"%d",++counter);
				SetWindowText(hDlg,p_buff);
			}
			//ODBCؒf
			Close(&henv,&hdbc,&hstmt);

			//t@C
			fclose(rfp);
			fclose(wfp);
		}
	}



	//ʓ͂L
	SetWindowText(hDlg,"");
	EnableWindow(GetDlgItem(hDlg,IDC_EDIT1),true);
	EnableWindow(GetDlgItem(hDlg,IDC_BUTTON1),true);
	EnableWindow(GetDlgItem(hDlg,IDC_BUTTON2),true);
	//}`Xbh΍
	ReleaseMutex( hIOMutex);
}

int WINAPI WinMain(HINSTANCE hCurInst,HINSTANCE hPrevInst,
					LPSTR lpsCmdLine,int nCmdShow ){
	hDlg=CreateDialog(hCurInst,MAKEINTRESOURCE(IDD_DIALOG1),NULL,(DLGPROC)DlgProc1);
	ShowWindow(hDlg,SW_NORMAL);					
						
	if(basic_init()) MessageBox(NULL,"C^v^̏Ɏs܂\nC^v^̎st@CmFĂ","abasic",0);

	MSG msg;
	BOOL bRet;

	while((bRet = GetMessage(&msg,NULL,0,0)) != 0){
		if(bRet == -1){
			MessageBox(NULL,"GetMessage ERR","Error",MB_OK);
			break;
		}else{
			if(!IsDialogMessage(hDlg,&msg)){ //TABL[ŃRg[ړɕKv
				TranslateMessage(&msg); 
				DispatchMessage(&msg); 
			} 
		}
	}
	return (int)msg.wParam;
}

//_CAOvV[W[
BOOL CALLBACK DlgProc1(HWND hDlg,UINT msg,WPARAM wp,LPARAM lp){
	switch (msg){
		case WM_SHOWWINDOW:
			break;
		case WM_PAINT:
			break;
		case WM_TIMER:
			break;
		case WM_COMMAND:
			switch (LOWORD(wp)){
				case IDC_BUTTON1:
					OpenFileDlg(hDlg,filename,sizeof(filename));
					SetWindowText(GetDlgItem(hDlg,IDC_EDIT1),filename);
					break;
				case IDC_BUTTON2:
					GetWindowText(GetDlgItem(hDlg,IDC_EDIT1),filename,sizeof(filename));
					_beginthread((void(*)(void*))thread,0,filename);//Xbh̃X^[g
					break;
			}
			break;
		case WM_CLOSE:
			DestroyWindow(hDlg);
			PostQuitMessage(0);
		break;
	}
	return FALSE;
}

==> abasic_0_0_7_7.zip: abasic_0_0_7_7/sample/sql/main.cpp <==
//WindowsAvP[VɑgݍŃf[^x[X𑀍삷Tv
#include <stdio.h>
#include <string.h>
#include <windows.h>
#include <process.h>
#include "resource.h"
#include "../abasic/ap_if.h"
#include "sql.h"

#pragma warning( disable : 4996 )

void OpenFileDlg(HWND hWnd,char*filename,int buffSize);
void thread(char*filename);
int WINAPI WinMain(HINSTANCE hCurInst,HINSTANCE hPrevInst,LPSTR lpsCmdLine,int nCmdShow );
BOOL CALLBACK DlgProc1(HWND,UINT,WPARAM,LPARAM);

HWND hDlg;
char filename[1024]="";
char titlebar[1024];
static char buff[65535];
static char p_buff[65535];
//}`Xbh΍
HANDLE     hIOMutex = CreateMutex (NULL, FALSE, NULL);

//t@C_CAO̕\
void OpenFileDlg(HWND hWnd,char*filename,int buffSize){
	OPENFILENAME OpenFileName;
	memset(&OpenFileName,0,sizeof(OPENFILENAME));
	OpenFileName.lStructSize=sizeof(OPENFILENAME);
	OpenFileName.hwndOwner = hWnd;
	OpenFileName.lpstrFilter =
					TEXT("*.txt (TXTt@C)\0*.txt\0")
					TEXT("*.dat (DATt@C)\0*.dat\0")
					TEXT("*.csv (CSVt@C)\0*.csv\0")
					TEXT("*.tsv (TSVt@C)\0*.tsv\0")
					TEXT("*.* (̑)\0*.*\0\0");
	OpenFileName.nFilterIndex =0;
	OpenFileName.lpstrFile = filename;
	OpenFileName.nMaxFile = buffSize;
	OpenFileName.lpstrTitle = "t@CJ";
	OpenFileName.Flags = OFN_FILEMUSTEXIST | OFN_HIDEREADONLY | OFN_NOCHANGEDIR;
	if(!GetOpenFileName(&OpenFileName)) filename[0]='\0';
}

//[J[Xbh
void thread(char*filename){
	//}`Xbh΍
	WaitForSingleObject( hIOMutex, INFINITE );
	//ʓ͂𖳌
	EnableWindow(GetDlgItem(hDlg,IDC_EDIT1),false);
	EnableWindow(GetDlgItem(hDlg,IDC_BUTTON1),false);
	EnableWindow(GetDlgItem(hDlg,IDC_BUTTON2),false);

	HENV   henv=NULL;//ODBC nh
	HDBC   hdbc=NULL;//ODBC ڑnh
	HSTMT  hstmt=NULL;//ODBC Xe[ggEnh
	
	char sql_source[256];
	char sql_user[256];
	char sql_pass[256];

	//C^v^̊֐inits
	basic_func("init");

	//C^v^ODBCڑ擾
	strcpy(sql_source,(char*)basic_getVari("sql_source"));
	strcpy(sql_user,(char*)basic_getVari("sql_user"));
	strcpy(sql_pass,(char*)basic_getVari("sql_pass"));

	//o^JEgJE^
	int counter=0;

	FILE * wfp;
	//Ot@CJ
	if((wfp=fopen("./log.txt","w"))==NULL){
		MessageBox(hDlg,"t@Cۑł܂","t@Cۑł܂",0);
	}else{
		FILE * rfp;
		//Ҍf[^t@CJ
		if((rfp=fopen(filename,"r"))==NULL){
			MessageBox(hDlg,"t@CJ܂","t@CJ܂",0);
		}else{
			while(fgets(buff,sizeof(buff),rfp)!=NULL){
				if(0==counter%100){
					//ODBCؒf
					Close(&henv,&hdbc,&hstmt);
					//ڑ ODBCf[^\[X [U[ pX[h
					if(!Connect(sql_source,sql_user,sql_pass,&henv,&hdbc,&hstmt)){
						MessageBox(hDlg,"ODBCڑG[","ODBCڑG[",0);
						return;
					}
				}
				//CR  LF 菜
				char*pos=buff;
				while(*pos){
					if(0x0D==*pos || 0x0A==*pos){
						*pos='\0';
						break;
					}
					pos++;
				}

				//C^v^̕ϐdataɃt@C̈ŝ܂܏
				basic_setVari("data",buff);
				//C^v^̊֐runs邽߂̏
				basic_setVari("callback","@run");
				//gUNV̊Jn R~bgOFFɂ
				if('1'!=*basic_getVari("debug")) SQLSetConnectOption( hdbc, SQL_AUTOCOMMIT, SQL_AUTOCOMMIT_OFF );
				
				do{
					//C^v^̃R[擾
					strcpy(p_buff,(const char*)basic_getVari("callback"));
					//R[i[ĂϐNA
					basic_setVari("callback","");
					//C^v^s
					basic_goto(p_buff);
					//C^v^֓nʂ
					basic_setVari("sql_result","");

					//C^v^ō\G[ꍇDB[obNI
					if('\0'!=*basic_getVari("system.err.line")){
						MessageBox(NULL,(char*)basic_getVari("system.err.line"),"C^v^\G[",0);
						MessageBox(NULL,(char*)basic_getVari("system.err.msg"),"\G[bZ[W",0);
						SQLTransact( henv, hdbc, SQL_ROLLBACK );
						Close(&henv,&hdbc,&hstmt);
						return;
					}

					//C^v^sSQL擾
					sprintf(p_buff,"%s",basic_getVari("sql"));
					//擾̕ϐNA
					basic_setVari("sql","");

					//sSQL݂s
					if(*p_buff){
						//C^v^̕ϐsqlɊi[ꂽSQLt@Cɕۑ
						fprintf(wfp,"%s\n",p_buff);
						fflush(wfp);

						//SQL̎s
						if(!Execute(&henv,&hdbc,&hstmt,p_buff)){
							MessageBox(hDlg,p_buff,"SQLG[",0);
							SQLTransact( henv, hdbc, SQL_ROLLBACK );
							Close(&henv,&hdbc,&hstmt);
							return;
						}
						
						//ʂ̃J̐߂
						short cols=0;
						SQLNumResultCols(hstmt, &cols);
						//SQĽʂɖ߂l
						if(cols){
							unsigned char  str[256];//tB[hőTCY
							long le;//NULL̔ -1NULL

							//AvP[Vϐւ̗̃oCh(ϐɊ֘At)
							SQLBindCol(hstmt, 1, SQL_C_CHAR, &str, (SDWORD)sizeof(str),&le);

							while(1){
								RETCODE rc = SQLFetch(hstmt);

								if( rc == SQL_NO_DATA_FOUND )
									break;
								if( rc != SQL_SUCCESS && rc != SQL_SUCCESS_WITH_INFO ) {
									//DBG[
									MessageBox(NULL,"DBG[","DBG[",0);
									SQLTransact( henv, hdbc, SQL_ROLLBACK );
									Close(&henv,&hdbc,&hstmt);
									return;
								}
								//ʂ̖߂lC^v^֕ԂϐɊi[
								basic_setVari("sql_result",(char*)str);
							}

							SQLFreeStmt(hstmt, SQL_DROP);//Xe[ggEnh̉
							SQLAllocStmt(hdbc, &hstmt);//Xe[ggEnh̍Ċ蓖
						}
					}
				}while(*(basic_getVari("callback")));//R[obNw肳ĂJԂ

				//gUNV̏I
				if('1'!=*basic_getVari("debug")) SQLTransact( henv, hdbc, SQL_COMMIT );
				
				//ʏɏꂽJE^̐\
				sprintf(p_buff,"%s Line:%d",titlebar,++counter);
				SetWindowText(hDlg,p_buff);
			}
			//ODBCؒf
			Close(&henv,&hdbc,&hstmt);

			//t@C
			fclose(rfp);
			fclose(wfp);
		}
	}



	//ʓ͂L
	SetWindowText(hDlg,titlebar);
	EnableWindow(GetDlgItem(hDlg,IDC_EDIT1),true);
	EnableWindow(GetDlgItem(hDlg,IDC_BUTTON1),true);
	EnableWindow(GetDlgItem(hDlg,IDC_BUTTON2),true);
	//}`Xbh΍
	ReleaseMutex( hIOMutex);
}

int WINAPI WinMain(HINSTANCE hCurInst,HINSTANCE hPrevInst,
					LPSTR lpsCmdLine,int nCmdShow ){
	hDlg=CreateDialog(hCurInst,MAKEINTRESOURCE(IDD_DIALOG1),NULL,(DLGPROC)DlgProc1);
	ShowWindow(hDlg,SW_NORMAL);					
						
	if(basic_load("main.txt")) MessageBox(NULL,"C^v^̏Ɏs܂\nC^v^̎st@CmFĂ","error",0);
	//C^v^̊֐inits
	basic_func("init");
	strcpy(titlebar,(char*)basic_getVari("titlebar"));

	MSG msg;
	BOOL bRet;

	while((bRet = GetMessage(&msg,NULL,0,0)) != 0){
		if(bRet == -1){
			MessageBox(NULL,"GetMessage ERR","Error",MB_OK);
			break;
		}else{
			if(!IsDialogMessage(hDlg,&msg)){ //TABL[ŃRg[ړɕKv
				TranslateMessage(&msg); 
				DispatchMessage(&msg); 
			} 
		}
	}
	return (int)msg.wParam;
}

//ŏ̕`擾ϐ
int first;

//_CAOvV[W[
BOOL CALLBACK DlgProc1(HWND hDlg,UINT msg,WPARAM wp,LPARAM lp){
	switch (msg){
		case WM_INITDIALOG:
			break;
		case WM_SHOWWINDOW:
			break;
		case WM_PAINT:
			if(!first){
				SetWindowText(hDlg,titlebar);
				first=1;
			}
			break;
		case WM_TIMER:
			break;
		case WM_COMMAND:
			switch (LOWORD(wp)){
				case IDC_BUTTON1:
					OpenFileDlg(hDlg,filename,sizeof(filename));
					SetWindowText(GetDlgItem(hDlg,IDC_EDIT1),filename);
					break;
				case IDC_BUTTON2:
					GetWindowText(GetDlgItem(hDlg,IDC_EDIT1),filename,sizeof(filename));
					_beginthread((void(*)(void*))thread,0,filename);//Xbh̃X^[g
					break;
			}
			break;
		case WM_CLOSE:
			DestroyWindow(hDlg);
			PostQuitMessage(0);
		break;
	}
	return FALSE;
}
